module.exports = defineTest({
	description: 'does not fail for cyclic assignments'
});
